# Generated by roxygen2: do not edit by hand

S3method("[",PSEstimate)
S3method(coef,PStrataFit)
S3method(contrast,PSEstimate)
S3method(contrast,PStrataFit)
S3method(diagnostics,PStrataFit)
S3method(estimate,PStrataFit)
S3method(fit,PStrataModel)
S3method(formula,PStrataFit)
S3method(nobs,PStrataFit)
S3method(plot,PSContrast)
S3method(plot,PSEstimate)
S3method(plot,PStrataFit)
S3method(print,PSContrast)
S3method(print,PSEstimate)
S3method(print,PStrataFit)
S3method(print,PStrataFitSurvival)
S3method(print,PStrataModel)
S3method(print,summary.PStrataFit)
S3method(summary,PSEstimate)
S3method(summary,PStrataFit)
S3method(summary,PStrataModel)
export(PStrataModel)
export(contrast)
export(diagnostics)
export(estimate)
export(fit)
export(make_stancode)
export(prior_cauchy)
export(prior_chisq)
export(prior_exponential)
export(prior_flat)
export(prior_gamma)
export(prior_inv_chisq)
export(prior_inv_gamma)
export(prior_lasso)
export(prior_logistic)
export(prior_normal)
export(prior_t)
export(prior_weibull)
export(stancode.PStrataFit)
export(survival)
importFrom(stats,coef)
importFrom(stats,formula)
importFrom(stats,nobs)
